import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface IdConfig extends cdktf.TerraformMetaArguments {
    /**
     * The number of random bytes to produce. The minimum value is 1, which produces eight bits of randomness.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/id#byte_length Id#byte_length}
     *
     * @stability stable
     */
    readonly byteLength: number;
    /**
     * Arbitrary map of values that, when changed, will trigger recreation of resource.
     *
     * See [the main provider documentation](../index.html) for more information.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/id#keepers Id#keepers}
     *
     * @stability stable
     */
    readonly keepers?: {
        [key: string]: string;
    };
    /**
     * Arbitrary string to prefix the output value with.
     *
     * This string is supplied as-is, meaning it is not guaranteed to be URL-safe or base64 encoded.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/id#prefix Id#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/random/r/id random_id}.
 *
 * @stability stable
 */
export declare class Id extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/random/r/id random_id} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IdConfig);
    /**
     * @stability stable
     */
    get b64Std(): string;
    /**
     * @stability stable
     */
    get b64Url(): string;
    private _byteLength?;
    /**
     * @stability stable
     */
    get byteLength(): number;
    /**
     * @stability stable
     */
    set byteLength(value: number);
    /**
     * @stability stable
     */
    get byteLengthInput(): number | undefined;
    /**
     * @stability stable
     */
    get dec(): string;
    /**
     * @stability stable
     */
    get hex(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _keepers?;
    /**
     * @stability stable
     */
    get keepers(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set keepers(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetKeepers(): void;
    /**
     * @stability stable
     */
    get keepersInput(): {
        [key: string]: string;
    } | undefined;
    private _prefix?;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    set prefix(value: string);
    /**
     * @stability stable
     */
    resetPrefix(): void;
    /**
     * @stability stable
     */
    get prefixInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
